;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "macher" "20260505.2003"
  "LLM implementation toolset."
  '((emacs "30.1")
    (gptel "0.9.9.3"))
  :url "https://github.com/kmontag/macher"
  :commit "293384813e4d40d878acea6ef970a20ebbc8ebea"
  :revdesc "293384813e4d"
  :keywords '("convenience" "gptel" "llm"))
